All of lore.kernel.org
 help / color / mirror / Atom feed
* Patch "usb: core: hub: use new USB_RESUME_TIMEOUT" has been added to the 4.0-stable tree
@ 2015-05-02 13:23 gregkh
  0 siblings, 0 replies; only message in thread
From: gregkh @ 2015-05-02 13:23 UTC (permalink / raw)
  To: balbi, gregkh; +Cc: stable, stable-commits


This is a note to let you know that I've just added the patch titled

    usb: core: hub: use new USB_RESUME_TIMEOUT

to the 4.0-stable tree which can be found at:
    http://www.kernel.org/git/?p=linux/kernel/git/stable/stable-queue.git;a=summary

The filename of the patch is:
     usb-core-hub-use-new-usb_resume_timeout.patch
and it can be found in the queue-4.0 subdirectory.

If you, or anyone else, feels it should not be added to the stable tree,
please let <stable@vger.kernel.org> know about it.


>From bbc78c07a51f6fd29c227b1220a9016e585358ba Mon Sep 17 00:00:00 2001
From: Felipe Balbi <balbi@ti.com>
Date: Fri, 13 Feb 2015 15:38:33 -0600
Subject: usb: core: hub: use new USB_RESUME_TIMEOUT

From: Felipe Balbi <balbi@ti.com>

commit bbc78c07a51f6fd29c227b1220a9016e585358ba upstream.

Make sure we're using the new macro, so our
resume signaling will always pass certification.

Signed-off-by: Felipe Balbi <balbi@ti.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

---
 drivers/usb/core/hub.c |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

--- a/drivers/usb/core/hub.c
+++ b/drivers/usb/core/hub.c
@@ -3406,10 +3406,10 @@ int usb_port_resume(struct usb_device *u
 	if (status) {
 		dev_dbg(&port_dev->dev, "can't resume, status %d\n", status);
 	} else {
 		/* drive resume for at least 20 msec */
 		dev_dbg(&udev->dev, "usb %sresume\n",
 				(PMSG_IS_AUTO(msg) ? "auto-" : ""));
-		msleep(25);
+		msleep(USB_RESUME_TIMEOUT);
 
 		/* Virtual root hubs can trigger on GET_PORT_STATUS to
 		 * stop resume signaling.  Then finish the resume


Patches currently in stable-queue which might be from balbi@ti.com are

queue-4.0/usb-host-xhci-use-new-usb_resume_timeout.patch
queue-4.0/usb-dwc2-hcd-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-sl811-use-new-usb_resume_timeout.patch
queue-4.0/usb-musb-use-new-usb_resume_timeout.patch
queue-4.0/usb-define-a-generic-usb_resume_timeout-macro.patch
queue-4.0/usb-host-oxu210hp-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-isp116x-use-new-usb_resume_timeout.patch
queue-4.0/usb-isp1760-hcd-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-r8a66597-use-new-usb_resume_timeout.patch
queue-4.0/usb-musb-core-fix-tx-rx-endpoint-order.patch
queue-4.0/usb-core-hub-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-fusbh200-use-new-usb_resume_timeout.patch
queue-4.0/usb-gadget-printer-enqueue-printer-s-response-for-setup-request.patch
queue-4.0/usb-host-ehci-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-uhci-use-new-usb_resume_timeout.patch
queue-4.0/usb-host-fotg210-use-new-usb_resume_timeout.patch
queue-4.0/usb-phy-find-the-right-match-in-devm_usb_phy_match.patch

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2015-05-02 13:24 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -3406,10 +3406,10 @@ int usb_port_resume(struct usb_device *u
 		dev_dbg(&port_dev->dev, "can't resume, status %d\n", status);
 	} else {
-		/* drive resume for at least 20 msec */
+		/* drive resume for USB_RESUME_TIMEOUT msec */
 		dev_dbg(&udev->dev, "usb %sresume\n",
 				(PMSG_IS_AUTO(msg) ? "auto-" : ""));
2015-05-02 13:23 Patch "usb: core: hub: use new USB_RESUME_TIMEOUT" has been added to the 4.0-stable tree gregkh

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.